<template>
  <basic-container>
    <ttable
      :table="table"
      @handleSelectionChange="handleSelectionChange"
      @currentChange="handleCurrentChange"
      :uploadInfo="uploadInfo"
      :prelang="prelang"
      :options="options"
      :bottomOffset="350"
      :ajaxFun="ajaxFun"
      :paramArr="handyTypeId"
      ref="commonHandymanTypeTable"
    >
      <template #toolbar></template>
    </ttable>
    <handymanTypeDialog
      :currshowlist.sync="showHandyMan"
      :joinId="this.joinId"
      @handleSelectionChange="addHandyMan"
    />
  </basic-container>
</template>
<script>
import ttable from '@/views/common/ztt-table'
import handymanTypeDialog from './handymantype_form'
import { saveRelation } from '../../../api/product/artificialinformationjoin'
import {
  delHandyTypeRelation,
  fetchHandymanType
} from '../../../api/product/handymantype'
export default {
  props: {
    currshowlist: {
      type: Boolean,
      default: false
    },
    multiSelect: {
      type: Boolean,
      default: false
    },
    joinId: {
      type: Number,
      default: 0
    }
  },
  data() {
    return {
      HandyManList: [],
      handyTypeId: [0],
      showHandyMan: false,
      ajaxFun: fetchHandymanType,
      innerVisible: false,
      listLoading: true,
      currentRow: null,
      multipleSelection: [],
      uploadInfo: {
        // 是否展示上传EXCEL以及对应的url
        isShow: false,
        url: ''
      },
      prelang: 'operation',
      options: {
        height: 300, // 默认高度-为了表头固定
        stripe: true, // 是否为斑马纹 table
        highlightCurrentRow: false, // 是否要高亮当前行
        border: true, // 是否有纵向边框
        lazy: false, // 是否需要懒加载
        fit: true, // 列的宽度是否自撑开
        multiSelect: false, //
        isGeneralSearch: true,
        seqNo: true,
        isRefresh: true, // 是否显示刷新按钮
        isShowHide: true, // 是否显示显影按钮
        isSearch: false, // 高级查询按钮
        defaultOrderBy: { column: 'id', direction: 'desc' }
      },
      table: {
        total: 0,
        currentPage: 1,
        pageSize: 20,
        data: [],
        // 标题
        column: [
          {
            minWidth: '140',
            prop: 'handymanNo',
            label: '人工编号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '140',
            prop: 'handymanName',
            label: '人工名称',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '140',
            prop: 'conversionCoefficient',
            label: '系数',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          }
        ],
        materialTypeList: [],
        toolbar: [
          {
            text: '新增',
            type: 'primary',
            fun: this.addOrUpdateHandle
          }
        ],
        operator: [
          {
            text: '删除',
            icon: 'el-icon-delete',
            type: 'text',
            size: 'small',
            fun: this.deleteHandle
          }
        ],
        operatorConfig: {
          fixed: 'right',
          label: '操作',
          width: 100,
          minWidth: 100
        }
      }
    }
  },
  components: {
    ttable,
    handymanTypeDialog
  },
  methods: {
    handleCurrentChange(row) {
      this.currentRow = row
    },
    handleSelectionChange(val) {
      // 多行选中
      this.multipleSelection = val
    },
    addOrUpdateHandle() {
      if (this.joinId != 0) {
        this.showHandyMan = true
      } else {
        this.$message.error('请选择至少一条人工类型')
      }
    },
    addHandyMan(param) {
      this.HandyManList = param
      if (this.HandyManList && this.HandyManList.length > 0) {
        const newHandyManList = new Array()
        for (let i = 0; i < this.HandyManList.length; i++) {
          newHandyManList.push(
            Object.assign({
              productionHandymanJoinId: this.joinId,
              productionHandymanId: this.HandyManList[i].id
            })
          )
        }
        // 3.请求后台
        saveRelation(newHandyManList).then((res) => {
          // 4.刷新页面
          this.$message.success('更新成功！')
          this.visible = false
          this.getData()
        })
      } else {
        this.$message.error('请选择至少一条人工类型')
      }
    },
    deleteHandle(row) {
      const handyRelationId = this.joinId
      this.$confirm('是否确认删除人工类型名称为：' + row.handymanName, '提示', {
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        closeOnClickModal: false,
        type: 'warning'
      })
        .then(function() {
          return delHandyTypeRelation(row.id, handyRelationId)
        })
        .then((data) => {
          this.$message.success('删除成功')
          this.getData()
        })
    },
    getData() {
      if (this.$refs.commonHandymanTypeTable !== undefined) {
        this.$refs.commonHandymanTypeTable.getDataList()
      }
    }
  },
  watch: {
    joinId: {
      handler(newValue, oldValue) {
        if (newValue) {
          this.handyTypeId = [this.joinId]
          this.$nextTick(() => {
            this.getData()
          })
        }
      },
      immediate: true
    }
  }
}
</script>
<style>
.part-dialog .el-dialog__header {
  padding: 10px 20px 10px;
}
.part-dialog .el-dialog__header .el-dialog__headerbtn {
  top: 10px;
}
.part-dialog .el-dialog__body {
  padding: 5px 20px;
}

.part-dialog .el-dialog__footer {
  padding: 5px 20px 10px;
}

.part-dialog .el-dialog__body .avue-crud__pagination {
  margin-top: 0px;
  margin-bottom: 5px;
}
</style>
